@@ -142,7 +142,7 @@ class Vehicle(object):
             json=json,
             headers=headers,
         )
-
+         
         if response.status_code == 200:
             result = response.json()
             self.accessToken = result["AuthenticationResult"]["AccessToken"]
@@ -157,9 +157,11 @@ class Vehicle(object):
             result["expiry_time"] = self.accessTokenExpiresAt
             result["expiry_date"] = time.localtime(self.accessTokenExpiresAt)
             self.writeToken(result)
-        if response.status_code == 401:
+        elif response.status_code == 401:
             _LOGGER.debug("401 response while refreshing token")
             self.auth()
+        else:
+            _LOGGER.debug(f"Refresh Token method did not return a 200 or 401 response. The response returned was: {response.text}")
     
     def writeToken(self, token):
         _LOGGER.debug("Write Token method called.")
